pub struct DependencyGraph<K: Eq + Hash, V> { /* private fields */ }Implementations
Sourceimpl<K: Eq + Hash + Clone + Debug, V> DependencyGraph<K, V>
impl<K: Eq + Hash + Clone + Debug, V> DependencyGraph<K, V>
Sourcepub fn new() -> DependencyGraph<K, V>
pub fn new() -> DependencyGraph<K, V>
Constructs a dependency graph and populates it with a root node.
Sourcepub fn insert_node(&mut self, key: K, data: V)
pub fn insert_node(&mut self, key: K, data: V)
Insert a node into the graph with |key| and attach |data| to the node.
If the node already exists, it is replaced.
Sourcepub fn insert_edge_from_root(
&mut self,
to: &K,
) -> Result<(), DependencyError<K>>
pub fn insert_edge_from_root( &mut self, to: &K, ) -> Result<(), DependencyError<K>>
Inserts an edge from the root of the graph to the node with key |to|.
If |to| doesn’t exist in the graph, return a MissingDependency error.
Sourcepub fn insert_edge(
&mut self,
from: &K,
to: &K,
) -> Result<(), DependencyError<K>>
pub fn insert_edge( &mut self, from: &K, to: &K, ) -> Result<(), DependencyError<K>>
Inserts an edge from the root of the graph from the node with key |from| to the node with key |to|.
If either |from| or |to| doesn’t exist in the graph, return a MissingDependency error.
Sourcepub fn resolve(self) -> Result<Vec<V>, DependencyError<K>>
pub fn resolve(self) -> Result<Vec<V>, DependencyError<K>>
Resolve the dependency graph, returning the data associated with each node in a path from the root node to its dependencies. For each node in the path all of its dependencies must appear after its position in the path. Any node that has no dependency chain from the root is pruned from the path.
If no such path is possible return a CircularDependency error.